==> dde-shell_0.0.23.tar.xz: BUILD/panels/dock/translations/org.deepin.ds.dock_pt_BR.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pt_BR">
<context>
    <name>main</name>
    <message>
        <location filename="../package/main.qml" line="148"/>
        <source>Indicator Style</source>
        <translation>Estilo do indicador</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="150"/>
        <source>Fashion Mode</source>
        <translation>Fashion</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="155"/>
        <source>Efficient Mode</source>
        <translation>Eficiente</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="161"/>
        <source>Alignment</source>
        <translation>Alinhamento</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="189"/>
        <source>Left</source>
        <translation>Esquerda</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="174"/>
        <source>Position</source>
        <translation>Posição</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="163"/>
        <source>Align Left</source>
        <translation>Alinhar à esquerda</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="168"/>
        <source>Align Center</source>
        <translation>Alinhamento central</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="178"/>
        <source>Top</source>
        <translation>Superior</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="183"/>
        <source>Bottom</source>
        <translation>Inferior</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="195"/>
        <source>Right</source>
        <translation>Direita</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="201"/>
        <source>Status</source>
        <translation>Status</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="203"/>
        <source>Keep Shown</source>
        <translation>Sempre exibir</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="208"/>
        <source>Keep Hidden</source>
        <translation>Manter oculto</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="214"/>
        <source>Smart Hide</source>
        <translation>Ocultar automaticamente</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="221"/>
        <source>Dock Settings</source>
        <translation>Configurações do dock</translation>
    </message>
</context>
</TS>

==> dde-shell_0.0.24.tar.xz: BUILD/panels/dock/translations/org.deepin.ds.dock_pt_BR.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pt_BR">
<context>
    <name>main</name>
    <message>
        <location filename="../package/main.qml" line="148"/>
        <source>Indicator Style</source>
        <translation>Estilo do indicador</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="150"/>
        <source>Fashion Mode</source>
        <translation>Fashion</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="155"/>
        <source>Efficient Mode</source>
        <translation>Eficiente</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="161"/>
        <source>Alignment</source>
        <translation>Alinhamento</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="189"/>
        <source>Left</source>
        <translation>Esquerda</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="174"/>
        <source>Position</source>
        <translation>Posição</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="163"/>
        <source>Align Left</source>
        <translation>Esquerda</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="168"/>
        <source>Align Center</source>
        <translation>Centro</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="178"/>
        <source>Top</source>
        <translation>Superior</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="183"/>
        <source>Bottom</source>
        <translation>Inferior</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="195"/>
        <source>Right</source>
        <translation>Direita</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="201"/>
        <source>Status</source>
        <translation>Exibição</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="203"/>
        <source>Keep Shown</source>
        <translation>Sempre exibir</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="208"/>
        <source>Keep Hidden</source>
        <translation>Sempre ocultar</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="214"/>
        <source>Smart Hide</source>
        <translation>Ocultar automaticamente</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="221"/>
        <source>Dock Settings</source>
        <translation>Configurações do dock</translation>
    </message>
</context>
</TS>
